@@ -1,41 +1,21 @@
 package Catalyst::Plugin::FormValidator;
 
-use strict;
-use MRO::Compat;
+use Moose::Role;
 use Data::FormValidator;
-
-our $VERSION = '0.093_1';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
-=head2 prepare
-
-Override Catalyst's prepare
-
-=cut
-
-sub prepare {
-    my $c = shift;
-    $c = $c->maybe::next::method(@_);
-    $c->{form} = Data::FormValidator->check( $c->request->parameters, {} );
-    return $c;
-}
-
-
-=head2 form
-
-$c->form object
-
-=cut 
-
 sub form {
-    my $c = shift;
-    if ( $_[0] ) {
-        my $form = $_[1] ? {@_} : $_[0];
-        $c->{form} =
-          Data::FormValidator->check( $c->request->parameters, $form );
+    my ($c, @opts) = @_;
+    if ( @opts ) {
+	    my $form = Data::FormValidator->check( $c->request->parameters, {@opts});
+        return $form;
+    }
+    else {
+        return Data::FormValidator->check( $c->request->parameters, {} );
     }
-    return $c->{form};
 }
+
 =head1 NAME
 
 Catalyst::Plugin::FormValidator - Data::FormValidator
